@@ -69,7 +69,7 @@ class PerItemShipping extends CGExtensions
    ---------------------------------------------------------*/
   function GetVersion()
   {
-    return '1.1';
+    return '1.1.1';
   }
 
 
@@ -216,7 +216,7 @@ class PerItemShipping extends CGExtensions
 
 	$n = 1;
 	if( $count_itemtype )
-	  $n += $one->quantity;
+	  $n = $one->quantity;
 
 	$running_cost += $shipping_cost * $n;
       }
