@@ -43,7 +43,7 @@ if( isset($params['shipping_field']) )
     $this->SetPreference('shipping_field',(int)$params['shipping_field']);
   }
 $this->SetPreference('itemcost',(float)trim($params['itemcost']));
-$this->SetPreference('count_itemtype',(float)trim($params['count_itemtype']));
+$this->SetPreference('count_itemtype',(int)trim($params['count_itemtype']));
 $this->RedirectToTab($id);
 
 #
