@@ -27,7 +27,8 @@ EOT;
 
 #I
 $lang['info_count_itemtype'] = 'If this option is selected, multiple items of the same type will be counted separately when calculating costs';
-$lang['info_itemprice'] = 'Specify the shipping cost per item';
+$lang['info_itemprice'] = 'Specify the shipping cost per item.  If the shipping field is not specified, or is invalid for the product this value is used as the shipping cost for an item';
+$lang['info_shipping_field'] = 'Specify the custom field from the Products module that will hold a shipping price for an item';
 $lang['itemprice'] = 'Per Item Price';
 
 #J
@@ -43,7 +44,7 @@ $lang['itemprice'] = 'Per Item Price';
 $lang['moddescription'] = 'A moduel that calculates fixed shipping costs based purely on the number of items';
 
 #N
-
+$lang['none'] = 'None';
 
 #O
 
@@ -60,6 +61,7 @@ $lang['preferences'] = 'Preferences';
 $lang['really_uninstall'] = 'Are you sure you want to uninstall this module?';
 
 #S
+$lang['shipping_field'] = 'Products Shipping Field';
 $lang['submit'] = 'Submit';
 
 #T
